#[non_exhaustive]pub struct ErrorMarker;Expand description
Indicates that an error occurred during encoding. This is a placeholder error that can be used by context implementations and is a ZST.
Error details are expected to be reported to the corresponding Context.