SystemContext

Struct SystemContext 

pub struct SystemContext<A, M> { /* private fields */ }
Available on crate feature alloc only.
A rich context dynamically allocating space using the system allocator.

Implementations

Source

impl<A, M> SystemContext<A, M>

pub fn new(alloc: A) -> Self

Construct a new context which uses allocations to store arbitrary amounts of diagnostics about decoding.

Or at least until we run out of memory.

pub fn include_type(&mut self) -> &mut Self

Configure the context to visualize type information, and not just variant and fields.

pub fn report(&self) -> Report<'_>

Generate a line-separated report of all collected errors.

pub fn errors(&self) -> Errors<'_>

Iterate over all collected errors.